# Yollor

[![Python](https://img.shields.io/badge/Python-3.11%2B-blue.svg)](https://www.python.org/)
[![License](https://img.shields.io/badge/License-CC0%201.0-blue.svg)](https://creativecommons.org/publicdomain/zero/1.0/)
[![Version](https://img.shields.io/badge/Version-2.0.0-blue.svg)](https://github.com/seu-usuario/sua-biblioteca/releases/tag/v1.0.0)
[![Version](https://img.shields.io/badge/Criador-Yyax13-purple.svg)](https://github.com/Yyax13)

Uma biblioteca Python para facilitar o uso de cores e sinais em seus projetos.

## Descrição

Yollor é uma biblioteca Python que oferece uma maneira simples de trabalhar com cores em seus projetos. Ela inclui uma função conveniente para aplicar cores a strings de texto.

## Instalação

Para instalar a biblioteca, baixe o arquivo yollor.py no [Repo Oficial](https://github.com/Yyax13/Yollor) e inclua o arquivo em seu projeto
> futuramente irei incluir a biblioteca no pypi (pip)

## Features

### Cores
- preto `c.black`
- vermelho `c.red`
- verde `c.green`
- marrom `c.brown`
- azul `c.blue`
- roxo `c.purple`
- ciano `c.cyan`
- cinza `c.gray`
- amarelo `c.yellow`

### Tags
Para usar tags, faça:

`t.tag_cor`

certifique-se de subistituir "tag" por uma dessas opçoes:
- tagn1
- tagn2
- tagn3
- tagn4
- tagn5
- tagn6
- tagn7
- tagn8
- tagn9
- tagn10
- minus
- quest
- more
- hashtag
- 
e "cor" por:

- black
- red
- green
- brown
- blue
- purple
- cyan
- gray
- yellow

## Licença

Esta biblioteca está disponível sob a Licença [MIT](LICENSE)

## Contribuição

Contribuições são bem-vindas! Sinta-se à vontade para abrir um problema ou enviar um pull request.

## Versão

Esta é a versão 2.0.0 da biblioteca.
